@@ -47,7 +47,10 @@ private Q_SLOTS:
     void testEncryptedMails();
     void testReturnSameMail();
     void testEmptySubject();
+    void testReplyHeader();
 
+    void testBug392239();
+    void testCRtoLF();
 private:
     KMime::Message::Ptr readAndParseMail(const QString &mailFile) const;
 };
